# cryptojwt

![License](https://img.shields.io/badge/license-Apache%202-blue.svg)
![Python version](https://img.shields.io/badge/python-3.6%20%7C%203.7%203.8-blue.svg)

An implementation of the JSON cryptographic specs JWS, JWE, JWK, and JWA [RFC 7515-7518] and JSON Web Token (JWT) [RFC 7519]

oidcmsg is the 1st layer in the
JWTConnect stack (cryptojwt, oidcmsg, oidcservice, oidcrp)
